import { useEffect, useState } from 'react'
import { Button, Checkbox, Flex, Modal } from 'antd'
import type { CheckboxProps } from 'antd'
import { useNavigate } from 'react-router'
import AppSteps from '@/components/AppSteps'
import { useAI } from '@/hooks/useAI'

const CheckboxGroup = Checkbox.Group

export default function ButtonModal() {
  const { isLoading, messages, post } = useAI()
  const lastMessage = messages[messages.length - 1]
  const [fields, setFields] = useState<any>([])
  const fieldsOptions = fields.map((field: any) => ({
    label: field.name,
    value: field.english_name,
  }))
  useEffect(() => {
    if (lastMessage?.role === 'assistant' && lastMessage?.content) {
      try {
        const parse = JSON.parse(lastMessage.content)
        setFields(parse.fields || [])
      } catch (error) {
        console.error(error)
      }
    }
  }, [lastMessage])
  const handleSearch = () => {
    post({
      response_format: {
        type: 'json_object',
      },
      messages: [
        {
          role: 'user',
          content: `找出数据集中有缺失值的字段，并返回 JSON 格式的结果。返回内容仅包含缺失字段的名称（name）及其对应的英文名（english_name）该字段有缺失值的数据有哪些，字段像主键的数据（desc）。如果没有缺失值，则返回空数组 []。
返回格式示例：
json
{
  "fields": [
    {"name": "字段1", "english_name": "字段英文名", "desc": "A000001、A000002..."},
    {"name": "字段2", "english_name": "字段英文名2", "desc": "A000001、A000002..."}
  ]
}
要求：
仅包含缺失值的字段（为空、null、undefined 等视为缺失）。
确保字段名称和英文名准确无误。
如果所有字段都有值，则返回 { "fields": [] }。`,
        },
      ],
    })
  }

  const navigate = useNavigate()

  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)

  const [checkedList, setCheckedList] = useState<string[]>([])

  const checkAll = fieldsOptions.length === checkedList.length
  const indeterminate = checkedList.length > 0 && checkedList.length < fieldsOptions.length

  const onChange = (list: string[]) => {
    setCheckedList(list)
  }

  const onCheckAllChange: CheckboxProps['onChange'] = (e) => {
    setCheckedList(e.target.checked ? fieldsOptions : [])
  }

  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const steps = [
    {
      title: '探索缺失值字段',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            探索结果：
            <Checkbox indeterminate={indeterminate} onChange={onCheckAllChange} checked={checkAll}>
              全选
            </Checkbox>
          </Flex>
          <CheckboxGroup options={fieldsOptions} value={checkedList} onChange={onChange} />
        </>
      ),
    },
    {
      title: '探索字段缺失值',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            探索结果：
          </Flex>
          {fields.map((item: any) => (
            <p key={item.english_name}>
              {item.name}: {item.desc}
            </p>
          ))}
        </>
      ),
    },
    {
      title: '填充字段缺失值',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            请选择需要填充的字段：
            <Checkbox indeterminate={indeterminate} onChange={onCheckAllChange} checked={checkAll}>
              全选
            </Checkbox>
          </Flex>
          <CheckboxGroup options={fieldsOptions} value={checkedList} onChange={onChange} />
        </>
      ),
    },
  ]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        缺失值
      </Button>
      <Modal
        title="缺失值探索"
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && (
              <Button type="primary" loading={isLoading} onClick={handleSearch}>
                智能探索缺失值字段
              </Button>
            )}
            {current === 0 && (
              <Button type="primary" disabled={!checkedList.length} onClick={() => next()}>
                进一步探索字段缺失值情况
              </Button>
            )}

            {current > 0 && <Button onClick={() => prev()}>上一步</Button>}
            {current > 0 && current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => navigate('/data/preprocess/null')}>
                跳转数据预处理
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '40px 0' }}>
          <AppSteps current={current} items={steps} style={{ marginBottom: 40 }} />
          <div>{steps[current].content}</div>
        </div>
      </Modal>
    </>
  )
}
